@@ -1,5 +1,4 @@
-from qtrangeslider import QRangeSlider
-from qtrangeslider._float_slider import QDoubleRangeSlider, QDoubleSlider
+from qtrangeslider import QDoubleRangeSlider, QDoubleSlider, QRangeSlider
 from qtrangeslider.qtcompat.QtCore import Qt
 from qtrangeslider.qtcompat.QtWidgets import QApplication, QVBoxLayout, QWidget
 
